@@ -2,5 +2,8 @@ from .pytime import  *
 from .dataset import *
 from .quant import *
 from .statisticmodel import *
+from  .utils import *
+__version__ = '0.1.23'
+check_version(__version__)
+
 
-__version__ = '0.1.22'
